@@ -7,7 +7,6 @@ from stack import parser, as_command
 import stack.utils as util
 from stack.main import main as cli_main
 from stack.decorators import ignore
-import sysconfig
 import traceback
 import subprocess
 
@@ -193,8 +192,12 @@ def serve(args) -> None:
     Serve current dir as as git daemon
     @argument --ip, help=IP addr
     @argument --port, help=Port
+    @argument --daemon, help=Run as daemon, default=1
     @argument --pidfile, help=Pid file, default=./git-daemon.pid
+    @argument --stop, default=0, help=stop git daemon
     '''
+    if bool(int(args.stop)):
+        return stop_serve(args)
     if os.path.exists(args.pidfile):
         ignore(stop_serve)(args)
     port = args.port or '30976'
@@ -202,7 +205,7 @@ def serve(args) -> None:
     util.info('git daemon will listen on %s:%s/.git' % (ip, port))
     cmd = 'git daemon --reuseaddr --base-path=. --export-all \
     --verbose --enable=receive-pack --port=%s --listen=%s --pid-file=./git-daemon.pid' % (port, ip)
-    local(cmd, block=False)
+    local(cmd, block=bool(int(args.daemon)))
 
 
 @as_command
